tw2.jqplugins.chosen
====================

Chosen is a JavaScript plugin that makes long,
unwieldy select boxes much more user-friendly.

For more information about Chosen, see the harvest website:
http://harvesthq.github.com/chosen/ or the Github repository
for chosen: https://github.com/harvesthq/chosen

Chosen is licensed under the MIT license and so is this
ToscaWidgets2 library.

The bundled version of Chosen in this project is
harvesthq/chosen@dc024d784ac1c1971fc968d519ed4ef3d9915f1c

